@@ -42,9 +42,6 @@
 #include <ImathTMatrix.h>
 #include <ImathTMatrixAlgo.h>
 
-#ifndef PLATFORM_WIN32
-    #include <assert.h>
-#endif
 
 using namespace Imath;
 
